# Changelog

## [v0.22.3](https://github.com/materialsproject/maggma/tree/v0.22.3) (2020-08-26)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.22.2...v0.22.3)

**Merged pull requests:**

- added context manager for stores [\#258](https://github.com/materialsproject/maggma/pull/258) ([jmmshn](https://github.com/jmmshn))
- Bump pre-commit from 2.6.0 to 2.7.1 [\#257](https://github.com/materialsproject/maggma/pull/257) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pydocstyle from 5.0.2 to 5.1.0 [\#256](https://github.com/materialsproject/maggma/pull/256) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pytest-mock from 3.2.0 to 3.3.0 [\#255](https://github.com/materialsproject/maggma/pull/255) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.22.2](https://github.com/materialsproject/maggma/tree/v0.22.2) (2020-08-21)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.22.1...v0.22.2)

**Merged pull requests:**

- Minor bug fixes to S3Store [\#253](https://github.com/materialsproject/maggma/pull/253) ([jmmshn](https://github.com/jmmshn))
- Bump mkdocs-material from 5.5.3 to 5.5.7 [\#250](https://github.com/materialsproject/maggma/pull/250) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pytest-cov from 2.10.0 to 2.10.1 [\#249](https://github.com/materialsproject/maggma/pull/249) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.22.1](https://github.com/materialsproject/maggma/tree/v0.22.1) (2020-08-11)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.22.0...v0.22.1)

**Merged pull requests:**

- Bump boto3 from 1.14.33 to 1.14.39 [\#248](https://github.com/materialsproject/maggma/pull/248) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump mongomock from 3.19.0 to 3.20.0 [\#246](https://github.com/materialsproject/maggma/pull/246) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pytest from 5.4.3 to 6.0.1 [\#245](https://github.com/materialsproject/maggma/pull/245) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump tqdm from 4.48.1 to 4.48.2 [\#244](https://github.com/materialsproject/maggma/pull/244) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump mkdocs-material from 5.5.1 to 5.5.3 [\#243](https://github.com/materialsproject/maggma/pull/243) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump fastapi from 0.60.1 to 0.61.0 [\#242](https://github.com/materialsproject/maggma/pull/242) ([dependabot[bot]](https://github.com/apps/dependabot))
- accept int as sort keys instead of Sort\(\) in .query\(\) and .groupby\(\) [\#241](https://github.com/materialsproject/maggma/pull/241) ([rkingsbury](https://github.com/rkingsbury))
- Bump boto3 from 1.14.28 to 1.14.33 [\#240](https://github.com/materialsproject/maggma/pull/240) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pymongo from 3.10.1 to 3.11.0 [\#239](https://github.com/materialsproject/maggma/pull/239) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump uvicorn from 0.11.7 to 0.11.8 [\#238](https://github.com/materialsproject/maggma/pull/238) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump mkdocs-material from 5.4.0 to 5.5.1 [\#237](https://github.com/materialsproject/maggma/pull/237) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump tqdm from 4.48.0 to 4.48.1 [\#236](https://github.com/materialsproject/maggma/pull/236) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump uvicorn from 0.11.6 to 0.11.7 [\#235](https://github.com/materialsproject/maggma/pull/235) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump uvicorn from 0.11.5 to 0.11.6 [\#234](https://github.com/materialsproject/maggma/pull/234) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump fastapi from 0.59.0 to 0.60.1 [\#233](https://github.com/materialsproject/maggma/pull/233) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump boto3 from 1.14.22 to 1.14.28 [\#231](https://github.com/materialsproject/maggma/pull/231) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump numpy from 1.19.0 to 1.19.1 [\#230](https://github.com/materialsproject/maggma/pull/230) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump tqdm from 4.47.0 to 4.48.0 [\#229](https://github.com/materialsproject/maggma/pull/229) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump mkdocstrings from 0.12.1 to 0.12.2 [\#228](https://github.com/materialsproject/maggma/pull/228) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump dnspython from 1.16.0 to 2.0.0 [\#227](https://github.com/materialsproject/maggma/pull/227) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump hvac from 0.10.4 to 0.10.5 [\#226](https://github.com/materialsproject/maggma/pull/226) ([dependabot[bot]](https://github.com/apps/dependabot))
- Update setup.py [\#225](https://github.com/materialsproject/maggma/pull/225) ([jmmshn](https://github.com/jmmshn))

## [v0.22.0](https://github.com/materialsproject/maggma/tree/v0.22.0) (2020-07-16)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.21.0...v0.22.0)

**Merged pull requests:**

- Bump boto3 from 1.14.20 to 1.14.22 [\#224](https://github.com/materialsproject/maggma/pull/224) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pydantic from 1.6 to 1.6.1 [\#223](https://github.com/materialsproject/maggma/pull/223) ([dependabot[bot]](https://github.com/apps/dependabot))
- Ensure Metadata in Documents from GridFS [\#222](https://github.com/materialsproject/maggma/pull/222) ([shyamd](https://github.com/shyamd))
- Bump monty from 3.0.2 to 3.0.4 [\#221](https://github.com/materialsproject/maggma/pull/221) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-mock from 3.1.1 to 3.2.0 [\#220](https://github.com/materialsproject/maggma/pull/220) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydantic from 1.5.1 to 1.6 [\#219](https://github.com/materialsproject/maggma/pull/219) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.14.16 to 1.14.20 [\#218](https://github.com/materialsproject/maggma/pull/218) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.12.0 to 0.12.1 [\#217](https://github.com/materialsproject/maggma/pull/217) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.58.1 to 0.59.0 [\#216](https://github.com/materialsproject/maggma/pull/216) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.14.12 to 1.14.16 [\#215](https://github.com/materialsproject/maggma/pull/215) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 2.5.1 to 2.6.0 [\#214](https://github.com/materialsproject/maggma/pull/214) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Projection\_Builder tests [\#213](https://github.com/materialsproject/maggma/pull/213) ([acrutt](https://github.com/acrutt))
- Bump mkdocs-material from 5.3.2 to 5.4.0 [\#212](https://github.com/materialsproject/maggma/pull/212) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-asyncio from 0.12.0 to 0.14.0 [\#211](https://github.com/materialsproject/maggma/pull/211) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.46.1 to 4.47.0 [\#210](https://github.com/materialsproject/maggma/pull/210) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mypy from 0.781 to 0.782 [\#209](https://github.com/materialsproject/maggma/pull/209) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.14.7 to 1.14.12 [\#208](https://github.com/materialsproject/maggma/pull/208) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.58.0 to 0.58.1 [\#207](https://github.com/materialsproject/maggma/pull/207) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- \[WIP\] Proper multithreading and msgpack fix [\#205](https://github.com/materialsproject/maggma/pull/205) ([jmmshn](https://github.com/jmmshn))
- Bump pytest-cov from 2.9.0 to 2.10.0 [\#198](https://github.com/materialsproject/maggma/pull/198) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Fix projection\_builder.update\_targets\(\) [\#179](https://github.com/materialsproject/maggma/pull/179) ([acrutt](https://github.com/acrutt))

## [v0.21.0](https://github.com/materialsproject/maggma/tree/v0.21.0) (2020-06-22)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.20.0...v0.21.0)

**Merged pull requests:**

- Bump numpy from 1.18.5 to 1.19.0 [\#204](https://github.com/materialsproject/maggma/pull/204) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mypy from 0.780 to 0.781 [\#203](https://github.com/materialsproject/maggma/pull/203) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.11.4 to 0.12.0 [\#202](https://github.com/materialsproject/maggma/pull/202) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump hvac from 0.10.3 to 0.10.4 [\#201](https://github.com/materialsproject/maggma/pull/201) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.14.2 to 1.14.7 [\#200](https://github.com/materialsproject/maggma/pull/200) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.3.0 to 5.3.2 [\#199](https://github.com/materialsproject/maggma/pull/199) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.13.24 to 1.14.2 [\#197](https://github.com/materialsproject/maggma/pull/197) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 2.4.0 to 2.5.1 [\#196](https://github.com/materialsproject/maggma/pull/196) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.2.3 to 5.3.0 [\#195](https://github.com/materialsproject/maggma/pull/195) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydash from 4.7.6 to 4.8.0 [\#194](https://github.com/materialsproject/maggma/pull/194) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.55.1 to 0.58.0 [\#193](https://github.com/materialsproject/maggma/pull/193) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump flake8 from 3.8.2 to 3.8.3 [\#192](https://github.com/materialsproject/maggma/pull/192) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.11.3 to 0.11.4 [\#191](https://github.com/materialsproject/maggma/pull/191) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mypy from 0.770 to 0.780 [\#190](https://github.com/materialsproject/maggma/pull/190) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.13.19 to 1.13.24 [\#189](https://github.com/materialsproject/maggma/pull/189) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.2.2 to 5.2.3 [\#188](https://github.com/materialsproject/maggma/pull/188) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.46.0 to 4.46.1 [\#187](https://github.com/materialsproject/maggma/pull/187) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-mock from 3.1.0 to 3.1.1 [\#186](https://github.com/materialsproject/maggma/pull/186) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump numpy from 1.18.4 to 1.18.5 [\#185](https://github.com/materialsproject/maggma/pull/185) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest from 5.4.2 to 5.4.3 [\#184](https://github.com/materialsproject/maggma/pull/184) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.11.2 to 0.11.3 [\#183](https://github.com/materialsproject/maggma/pull/183) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Reconstruct metadata from index in S3 Store [\#182](https://github.com/materialsproject/maggma/pull/182) ([jmmshn](https://github.com/jmmshn))
- Bump boto3 from 1.13.16 to 1.13.19 [\#181](https://github.com/materialsproject/maggma/pull/181) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- MapBuilder retry\_failed Fix [\#180](https://github.com/materialsproject/maggma/pull/180) ([acrutt](https://github.com/acrutt))
- Bump mkdocs-material from 5.1.7 to 5.2.1 [\#178](https://github.com/materialsproject/maggma/pull/178) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.13.11 to 1.13.16 [\#177](https://github.com/materialsproject/maggma/pull/177) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.11.1 to 0.11.2 [\#176](https://github.com/materialsproject/maggma/pull/176) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.54.2 to 0.55.1 [\#175](https://github.com/materialsproject/maggma/pull/175) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-cov from 2.8.1 to 2.9.0 [\#174](https://github.com/materialsproject/maggma/pull/174) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump flake8 from 3.8.1 to 3.8.2 [\#173](https://github.com/materialsproject/maggma/pull/173) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump hvac from 0.10.1 to 0.10.3 [\#172](https://github.com/materialsproject/maggma/pull/172) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.1.6 to 5.1.7 [\#171](https://github.com/materialsproject/maggma/pull/171) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.13.6 to 1.13.11 [\#170](https://github.com/materialsproject/maggma/pull/170) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.54.1 to 0.54.2 [\#169](https://github.com/materialsproject/maggma/pull/169) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 2.3.0 to 2.4.0 [\#168](https://github.com/materialsproject/maggma/pull/168) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pycodestyle from 2.5.0 to 2.6.0 [\#167](https://github.com/materialsproject/maggma/pull/167) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs from 1.1 to 1.1.2 [\#166](https://github.com/materialsproject/maggma/pull/166) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.11.0 to 0.11.1 [\#165](https://github.com/materialsproject/maggma/pull/165) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump flake8 from 3.7.9 to 3.8.1 [\#164](https://github.com/materialsproject/maggma/pull/164) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.12.46 to 1.13.6 [\#163](https://github.com/materialsproject/maggma/pull/163) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump aioitertools from 0.6.1 to 0.7.0 [\#162](https://github.com/materialsproject/maggma/pull/162) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest from 5.4.1 to 5.4.2 [\#161](https://github.com/materialsproject/maggma/pull/161) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.1.5 to 5.1.6 [\#160](https://github.com/materialsproject/maggma/pull/160) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump numpy from 1.18.3 to 1.18.4 [\#159](https://github.com/materialsproject/maggma/pull/159) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-asyncio from 0.11.0 to 0.12.0 [\#158](https://github.com/materialsproject/maggma/pull/158) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump uvicorn from 0.11.3 to 0.11.5 [\#157](https://github.com/materialsproject/maggma/pull/157) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.1.3 to 5.1.5 [\#156](https://github.com/materialsproject/maggma/pull/156) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.45.0 to 4.46.0 [\#155](https://github.com/materialsproject/maggma/pull/155) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- MapBuilder retry\_failed bug [\#111](https://github.com/materialsproject/maggma/pull/111) ([acrutt](https://github.com/acrutt))

## [v0.20.0](https://github.com/materialsproject/maggma/tree/v0.20.0) (2020-05-02)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.19.1...v0.20.0)

**Merged pull requests:**

- Bump mkdocs-material-components from 1.10.11 to 1.10.14 [\#153](https://github.com/materialsproject/maggma/pull/153) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydantic from 1.5 to 1.5.1 [\#152](https://github.com/materialsproject/maggma/pull/152) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.10.3 to 0.11.0 [\#151](https://github.com/materialsproject/maggma/pull/151) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump aioitertools from 0.6.0 to 0.6.1 [\#150](https://github.com/materialsproject/maggma/pull/150) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-asyncio from 0.10.0 to 0.11.0 [\#149](https://github.com/materialsproject/maggma/pull/149) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.1.1 to 5.1.3 [\#148](https://github.com/materialsproject/maggma/pull/148) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.12.41 to 1.12.46 [\#147](https://github.com/materialsproject/maggma/pull/147) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 2.2.0 to 2.3.0 [\#146](https://github.com/materialsproject/maggma/pull/146) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Initial Drone Implementation [\#145](https://github.com/materialsproject/maggma/pull/145) ([wuxiaohua1011](https://github.com/wuxiaohua1011))
- Bump boto3 from 1.12.39 to 1.12.41 [\#144](https://github.com/materialsproject/maggma/pull/144) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump numpy from 1.18.2 to 1.18.3 [\#143](https://github.com/materialsproject/maggma/pull/143) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydantic from 1.4 to 1.5 [\#142](https://github.com/materialsproject/maggma/pull/142) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-mock from 3.0.0 to 3.1.0 [\#141](https://github.com/materialsproject/maggma/pull/141) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 5.1.0 to 5.1.1 [\#140](https://github.com/materialsproject/maggma/pull/140) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump hvac from 0.10.0 to 0.10.1 [\#139](https://github.com/materialsproject/maggma/pull/139) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-minify-plugin from 0.2.3 to 0.3.0 [\#138](https://github.com/materialsproject/maggma/pull/138) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.44.1 to 4.45.0 [\#137](https://github.com/materialsproject/maggma/pull/137) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 4.6.3 to 5.1.0 [\#136](https://github.com/materialsproject/maggma/pull/136) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.8.0 to 0.10.3 [\#135](https://github.com/materialsproject/maggma/pull/135) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.12.34 to 1.12.39 [\#134](https://github.com/materialsproject/maggma/pull/134) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.53.2 to 0.54.1 [\#133](https://github.com/materialsproject/maggma/pull/133) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump msgpack from 0.5.6 to 1.0.0 [\#132](https://github.com/materialsproject/maggma/pull/132) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump aioitertools from 0.5.1 to 0.6.0 [\#131](https://github.com/materialsproject/maggma/pull/131) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- parallel s3 store wrting [\#130](https://github.com/materialsproject/maggma/pull/130) ([jmmshn](https://github.com/jmmshn))
- Make GridFSStore query check files store first. [\#128](https://github.com/materialsproject/maggma/pull/128) ([munrojm](https://github.com/munrojm))

## [v0.19.1](https://github.com/materialsproject/maggma/tree/v0.19.1) (2020-04-06)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.19.0...v0.19.1)

## [v0.19.0](https://github.com/materialsproject/maggma/tree/v0.19.0) (2020-04-06)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.18.0...v0.19.0)

**Closed issues:**

- ISSUE: newer\_in method incompatible with GridFSStore [\#113](https://github.com/materialsproject/maggma/issues/113)

**Merged pull requests:**

- Fix async [\#129](https://github.com/materialsproject/maggma/pull/129) ([shyamd](https://github.com/shyamd))
- Bump boto3 from 1.12.11 to 1.12.34 [\#127](https://github.com/materialsproject/maggma/pull/127) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mypy from 0.761 to 0.770 [\#126](https://github.com/materialsproject/maggma/pull/126) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest from 5.3.5 to 5.4.1 [\#125](https://github.com/materialsproject/maggma/pull/125) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-mock from 2.0.0 to 3.0.0 [\#124](https://github.com/materialsproject/maggma/pull/124) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump uvicorn from 0.10.8 to 0.11.3 [\#123](https://github.com/materialsproject/maggma/pull/123) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydantic from 1.3 to 1.4 [\#122](https://github.com/materialsproject/maggma/pull/122) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.43.0 to 4.44.1 [\#121](https://github.com/materialsproject/maggma/pull/121) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 2.1.1 to 2.2.0 [\#119](https://github.com/materialsproject/maggma/pull/119) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump fastapi from 0.46.0 to 0.53.2 [\#118](https://github.com/materialsproject/maggma/pull/118) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.8.0 to 0.10.0 [\#117](https://github.com/materialsproject/maggma/pull/117) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump numpy from 1.18.1 to 1.18.2 [\#116](https://github.com/materialsproject/maggma/pull/116) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- small fixes [\#115](https://github.com/materialsproject/maggma/pull/115) ([jmmshn](https://github.com/jmmshn))
- Store updates [\#114](https://github.com/materialsproject/maggma/pull/114) ([jmmshn](https://github.com/jmmshn))
- \[WIP\] Add EndpointCluster and ClusterManager to maggma [\#66](https://github.com/materialsproject/maggma/pull/66) ([wuxiaohua1011](https://github.com/wuxiaohua1011))

## [v0.18.0](https://github.com/materialsproject/maggma/tree/v0.18.0) (2020-03-23)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.17.3...v0.18.0)

**Merged pull requests:**

- Amazon S3 store update [\#110](https://github.com/materialsproject/maggma/pull/110) ([munrojm](https://github.com/munrojm))

## [v0.17.3](https://github.com/materialsproject/maggma/tree/v0.17.3) (2020-03-18)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.17.2...v0.17.3)

## [v0.17.2](https://github.com/materialsproject/maggma/tree/v0.17.2) (2020-03-13)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.17.1...v0.17.2)

## [v0.17.1](https://github.com/materialsproject/maggma/tree/v0.17.1) (2020-03-12)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.16.1...v0.17.1)

**Merged pull requests:**

- Various Bug Fixes [\#109](https://github.com/materialsproject/maggma/pull/109) ([shyamd](https://github.com/shyamd))
- Bump mongomock from 3.18.0 to 3.19.0 [\#108](https://github.com/materialsproject/maggma/pull/108) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs from 1.0.4 to 1.1 [\#107](https://github.com/materialsproject/maggma/pull/107) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump hvac from 0.9.6 to 0.10.0 [\#106](https://github.com/materialsproject/maggma/pull/106) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 2.0.1 to 2.1.1 [\#105](https://github.com/materialsproject/maggma/pull/105) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-minify-plugin from 0.2.1 to 0.2.3 [\#104](https://github.com/materialsproject/maggma/pull/104) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.7.0 to 0.7.1 [\#103](https://github.com/materialsproject/maggma/pull/103) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.42.0 to 4.43.0 [\#102](https://github.com/materialsproject/maggma/pull/102) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocs-material from 4.6.0 to 4.6.3 [\#101](https://github.com/materialsproject/maggma/pull/101) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.11.9 to 1.12.11 [\#100](https://github.com/materialsproject/maggma/pull/100) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Addition of Projection Builder [\#99](https://github.com/materialsproject/maggma/pull/99) ([acrutt](https://github.com/acrutt))
- Fix issues with last\_updated in MapBuilder [\#98](https://github.com/materialsproject/maggma/pull/98) ([shyamd](https://github.com/shyamd))
- autonotebook for tqdm [\#97](https://github.com/materialsproject/maggma/pull/97) ([shyamd](https://github.com/shyamd))
- Bump pytest from 5.3.4 to 5.3.5 [\#96](https://github.com/materialsproject/maggma/pull/96) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 1.21.0 to 2.0.1 [\#95](https://github.com/materialsproject/maggma/pull/95) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydocstyle from 5.0.1 to 5.0.2 [\#94](https://github.com/materialsproject/maggma/pull/94) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))

## [v0.16.1](https://github.com/materialsproject/maggma/tree/v0.16.1) (2020-01-28)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.16.0...v0.16.1)

## [v0.16.0](https://github.com/materialsproject/maggma/tree/v0.16.0) (2020-01-28)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.15.0...v0.16.0)

**Closed issues:**

- Onotology generation from builder [\#59](https://github.com/materialsproject/maggma/issues/59)

**Merged pull requests:**

- Add MongoURIStore [\#93](https://github.com/materialsproject/maggma/pull/93) ([shyamd](https://github.com/shyamd))
- Update distinct to be more like mongo distinct [\#92](https://github.com/materialsproject/maggma/pull/92) ([shyamd](https://github.com/shyamd))
- Bump tqdm from 4.41.1 to 4.42.0 [\#91](https://github.com/materialsproject/maggma/pull/91) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump mkdocstrings from 0.6.1 to 0.7.0 [\#90](https://github.com/materialsproject/maggma/pull/90) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump boto3 from 1.10.10 to 1.11.9 [\#89](https://github.com/materialsproject/maggma/pull/89) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pre-commit from 1.20.0 to 1.21.0 [\#88](https://github.com/materialsproject/maggma/pull/88) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest-mock from 1.13.0 to 2.0.0 [\#87](https://github.com/materialsproject/maggma/pull/87) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Add count to maggma store [\#86](https://github.com/materialsproject/maggma/pull/86) ([shyamd](https://github.com/shyamd))

## [v0.15.0](https://github.com/materialsproject/maggma/tree/v0.15.0) (2020-01-23)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.14.1...v0.15.0)

**Closed issues:**

- Builder Reporting [\#78](https://github.com/materialsproject/maggma/issues/78)
- ZeroMQ based multi-node processing [\#76](https://github.com/materialsproject/maggma/issues/76)
- Add time limits to process\_item? \(Possibly just in MapBuilder?\) [\#45](https://github.com/materialsproject/maggma/issues/45)

**Merged pull requests:**

- Bump hvac from 0.9.5 to 0.9.6 [\#85](https://github.com/materialsproject/maggma/pull/85) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pydash from 4.7.5 to 4.7.6 [\#84](https://github.com/materialsproject/maggma/pull/84) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump numpy from 1.18.0 to 1.18.1 [\#83](https://github.com/materialsproject/maggma/pull/83) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pytest from 5.3.2 to 5.3.4 [\#82](https://github.com/materialsproject/maggma/pull/82) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump pymongo from 3.9.0 to 3.10.1 [\#81](https://github.com/materialsproject/maggma/pull/81) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- \[WIP\] Builder Reporting [\#80](https://github.com/materialsproject/maggma/pull/80) ([shyamd](https://github.com/shyamd))
- Updated GroupBuilder [\#79](https://github.com/materialsproject/maggma/pull/79) ([shyamd](https://github.com/shyamd))
- New Distributed Processor [\#77](https://github.com/materialsproject/maggma/pull/77) ([shyamd](https://github.com/shyamd))

## [v0.14.1](https://github.com/materialsproject/maggma/tree/v0.14.1) (2020-01-10)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.14.0...v0.14.1)

## [v0.14.0](https://github.com/materialsproject/maggma/tree/v0.14.0) (2020-01-10)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.13.0...v0.14.0)

**Closed issues:**

- Preserve last\_updated for MapBuilder [\#58](https://github.com/materialsproject/maggma/issues/58)
- Move away from mpi4py [\#51](https://github.com/materialsproject/maggma/issues/51)
- Run serial processor directly from builder [\#48](https://github.com/materialsproject/maggma/issues/48)
- Update while processing [\#42](https://github.com/materialsproject/maggma/issues/42)
- Running JSONStore.connect\(\) multiple times leads to undefined behavior [\#40](https://github.com/materialsproject/maggma/issues/40)
- get\_criteria directly invokes mongo commands [\#38](https://github.com/materialsproject/maggma/issues/38)
- Cursor timeouts common [\#35](https://github.com/materialsproject/maggma/issues/35)
- Possible solution to "stalled" Runner.run ? [\#29](https://github.com/materialsproject/maggma/issues/29)

**Merged pull requests:**

- Release Workflow for Github [\#75](https://github.com/materialsproject/maggma/pull/75) ([shyamd](https://github.com/shyamd))
- Documentation [\#74](https://github.com/materialsproject/maggma/pull/74) ([shyamd](https://github.com/shyamd))
- Bump jsonschema from 3.1.1 to 3.2.0 [\#73](https://github.com/materialsproject/maggma/pull/73) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump moto from 1.3.13 to 1.3.14 [\#72](https://github.com/materialsproject/maggma/pull/72) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump tqdm from 4.37.0 to 4.41.1 [\#71](https://github.com/materialsproject/maggma/pull/71) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Bump numpy from 1.17.3 to 1.18.0 [\#70](https://github.com/materialsproject/maggma/pull/70) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Reorg code [\#69](https://github.com/materialsproject/maggma/pull/69) ([shyamd](https://github.com/shyamd))
- Bump pytest from 5.3.1 to 5.3.2 [\#68](https://github.com/materialsproject/maggma/pull/68) ([dependabot-preview[bot]](https://github.com/apps/dependabot-preview))
- Updates for new monitoring services [\#67](https://github.com/materialsproject/maggma/pull/67) ([shyamd](https://github.com/shyamd))
- fix GridFSStore [\#64](https://github.com/materialsproject/maggma/pull/64) ([gpetretto](https://github.com/gpetretto))
- Massive refactoring to get ready for v1.0 [\#62](https://github.com/materialsproject/maggma/pull/62) ([shyamd](https://github.com/shyamd))
- Bug Fixes [\#61](https://github.com/materialsproject/maggma/pull/61) ([shyamd](https://github.com/shyamd))
- GridFSStore bug fix [\#60](https://github.com/materialsproject/maggma/pull/60) ([munrojm](https://github.com/munrojm))
- Fix Store serialization with @version [\#57](https://github.com/materialsproject/maggma/pull/57) ([mkhorton](https://github.com/mkhorton))
- Update builder to work with new monty [\#56](https://github.com/materialsproject/maggma/pull/56) ([mkhorton](https://github.com/mkhorton))

## [v0.13.0](https://github.com/materialsproject/maggma/tree/v0.13.0) (2019-03-29)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.12.0...v0.13.0)

**Merged pull requests:**

- Add timeout to MapBuilder, store process time [\#54](https://github.com/materialsproject/maggma/pull/54) ([mkhorton](https://github.com/mkhorton))
- Can update pyyaml req? [\#50](https://github.com/materialsproject/maggma/pull/50) ([dwinston](https://github.com/dwinston))
- Concat store [\#47](https://github.com/materialsproject/maggma/pull/47) ([shyamd](https://github.com/shyamd))

## [v0.12.0](https://github.com/materialsproject/maggma/tree/v0.12.0) (2018-11-19)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.11.0...v0.12.0)

## [v0.11.0](https://github.com/materialsproject/maggma/tree/v0.11.0) (2018-11-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.9.0...v0.11.0)

**Merged pull requests:**

- Better printing of validation erorrs [\#46](https://github.com/materialsproject/maggma/pull/46) ([mkhorton](https://github.com/mkhorton))
- Updates to JointStore and MapBuilder [\#44](https://github.com/materialsproject/maggma/pull/44) ([shyamd](https://github.com/shyamd))

## [v0.9.0](https://github.com/materialsproject/maggma/tree/v0.9.0) (2018-10-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.8.0...v0.9.0)

**Closed issues:**

- Non-obvious error message when trying to query a Store that hasn't been connected [\#41](https://github.com/materialsproject/maggma/issues/41)
- Criteria/properties order of MongoStore.query [\#37](https://github.com/materialsproject/maggma/issues/37)
- tqdm in Jupyter [\#33](https://github.com/materialsproject/maggma/issues/33)
- query args order [\#31](https://github.com/materialsproject/maggma/issues/31)

**Merged pull requests:**

- Simplification of Validator class + tests [\#39](https://github.com/materialsproject/maggma/pull/39) ([mkhorton](https://github.com/mkhorton))
- Fix for Jupyter detection for tqdm [\#36](https://github.com/materialsproject/maggma/pull/36) ([mkhorton](https://github.com/mkhorton))
- Add tqdm widget inside Jupyter [\#34](https://github.com/materialsproject/maggma/pull/34) ([mkhorton](https://github.com/mkhorton))
- Change update\_targets log level from debug to exception [\#32](https://github.com/materialsproject/maggma/pull/32) ([mkhorton](https://github.com/mkhorton))
- Jointstore [\#23](https://github.com/materialsproject/maggma/pull/23) ([montoyjh](https://github.com/montoyjh))

## [v0.8.0](https://github.com/materialsproject/maggma/tree/v0.8.0) (2018-08-22)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.6.5...v0.8.0)

**Merged pull requests:**

- \[WIP\] Improve/refactor examples and move inside maggma namespace [\#30](https://github.com/materialsproject/maggma/pull/30) ([dwinston](https://github.com/dwinston))
- Fix mrun with default num\_workers. Add test. [\#28](https://github.com/materialsproject/maggma/pull/28) ([dwinston](https://github.com/dwinston))

## [v0.6.5](https://github.com/materialsproject/maggma/tree/v0.6.5) (2018-06-07)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.6.4...v0.6.5)

## [v0.6.4](https://github.com/materialsproject/maggma/tree/v0.6.4) (2018-06-07)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.6.3...v0.6.4)

## [v0.6.3](https://github.com/materialsproject/maggma/tree/v0.6.3) (2018-06-07)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.6.2...v0.6.3)

**Merged pull requests:**

- Add MongograntStore [\#27](https://github.com/materialsproject/maggma/pull/27) ([dwinston](https://github.com/dwinston))

## [v0.6.2](https://github.com/materialsproject/maggma/tree/v0.6.2) (2018-06-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.6.1...v0.6.2)

## [v0.6.1](https://github.com/materialsproject/maggma/tree/v0.6.1) (2018-06-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.6.0...v0.6.1)

**Merged pull requests:**

- Help user if e.g. target store built without lu\_field [\#26](https://github.com/materialsproject/maggma/pull/26) ([dwinston](https://github.com/dwinston))

## [v0.6.0](https://github.com/materialsproject/maggma/tree/v0.6.0) (2018-05-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.5.0...v0.6.0)

**Implemented enhancements:**

- Progress Bar [\#21](https://github.com/materialsproject/maggma/issues/21)
- Query Engine equivalent [\#9](https://github.com/materialsproject/maggma/issues/9)

**Merged pull requests:**

- Progress Bars for Multiprocess Runner [\#24](https://github.com/materialsproject/maggma/pull/24) ([shyamd](https://github.com/shyamd))
- GridFS Store update: use metadata field, update removes old file\(s\) [\#20](https://github.com/materialsproject/maggma/pull/20) ([dwinston](https://github.com/dwinston))

## [v0.5.0](https://github.com/materialsproject/maggma/tree/v0.5.0) (2018-03-31)

[Full Changelog](https://github.com/materialsproject/maggma/compare/0.4.0...v0.5.0)

**Closed issues:**

- Need from pymongo collection [\#18](https://github.com/materialsproject/maggma/issues/18)

**Merged pull requests:**

- Useability updates [\#19](https://github.com/materialsproject/maggma/pull/19) ([shyamd](https://github.com/shyamd))

## [0.4.0](https://github.com/materialsproject/maggma/tree/0.4.0) (2018-02-28)

[Full Changelog](https://github.com/materialsproject/maggma/compare/0.3.0...0.4.0)

**Merged pull requests:**

- New Multiprocessor and MPI Processor [\#17](https://github.com/materialsproject/maggma/pull/17) ([shyamd](https://github.com/shyamd))
- groupby change for memory/jsonstore [\#16](https://github.com/materialsproject/maggma/pull/16) ([montoyjh](https://github.com/montoyjh))
- Rename Schema to Validator [\#15](https://github.com/materialsproject/maggma/pull/15) ([mkhorton](https://github.com/mkhorton))

## [0.3.0](https://github.com/materialsproject/maggma/tree/0.3.0) (2018-02-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.2.0...0.3.0)

**Implemented enhancements:**

- Vault enabled Store [\#8](https://github.com/materialsproject/maggma/issues/8)

**Merged pull requests:**

- PR for generic Schema class [\#14](https://github.com/materialsproject/maggma/pull/14) ([mkhorton](https://github.com/mkhorton))
- Issue 8 vault store [\#13](https://github.com/materialsproject/maggma/pull/13) ([shreddd](https://github.com/shreddd))
- adds grouping function and test to make aggregation-based builds [\#12](https://github.com/materialsproject/maggma/pull/12) ([montoyjh](https://github.com/montoyjh))

## [v0.2.0](https://github.com/materialsproject/maggma/tree/v0.2.0) (2018-01-01)

[Full Changelog](https://github.com/materialsproject/maggma/compare/v0.1.0...v0.2.0)

**Closed issues:**

- LU translation functions don't serialize [\#11](https://github.com/materialsproject/maggma/issues/11)

**Merged pull requests:**

- Mongolike mixin [\#10](https://github.com/materialsproject/maggma/pull/10) ([montoyjh](https://github.com/montoyjh))

## [v0.1.0](https://github.com/materialsproject/maggma/tree/v0.1.0) (2017-11-08)

[Full Changelog](https://github.com/materialsproject/maggma/compare/78ef2e8eacc051207350dc6abe886a403982aef8...v0.1.0)

**Closed issues:**

- ditch python 2 and support only 3? [\#3](https://github.com/materialsproject/maggma/issues/3)
- Seeking clarifications [\#1](https://github.com/materialsproject/maggma/issues/1)

**Merged pull requests:**

- Do not wait until all items are processed to update targets [\#7](https://github.com/materialsproject/maggma/pull/7) ([dwinston](https://github.com/dwinston))
- Run builder with either MPI or multiprocessing [\#6](https://github.com/materialsproject/maggma/pull/6) ([matk86](https://github.com/matk86))
- add lava code and tool execution script [\#5](https://github.com/materialsproject/maggma/pull/5) ([gilbertozp](https://github.com/gilbertozp))
- Add eclipse project files to .gitignore [\#2](https://github.com/materialsproject/maggma/pull/2) ([gilbertozp](https://github.com/gilbertozp))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
